@@ -20,9 +20,14 @@ class WhatsAppUpdate:
                     message.interactive["button_reply"]["title"]))
                 return message.interactive["button_reply"]["title"]
             elif message.interactive["type"] == "list_reply":
-                print("Interactive Message List: {}{}".format(
-                    message.interactive["list_reply"]["title"], message.interactive["list_reply"]["description"]))
-                return "{} {}".format(message.interactive["list_reply"]["title"], message.interactive["list_reply"]["description"])
+                if "description" in message.interactive["list_reply"]:
+                    print("Interactive Message List: {}{}".format(
+                        message.interactive["list_reply"]["title"], message.interactive["list_reply"]["description"]))
+                    return "{} {}".format(message.interactive["list_reply"]["title"], message.interactive["list_reply"]["description"])
+                else:
+                    print("Interactive Message List: {}".format(
+                        message.interactive["list_reply"]["title"]))
+                    return "{}".format(message.interactive["list_reply"]["title"])
             else:
                 print("There is no message text defined for this interactive type: {}".format(
                     message.interactive["type"]))
